# GANDALF
![Travis (.com)](https://img.shields.io/travis/com/deepio/gandalf)
![GitHub tag (latest by date)](https://img.shields.io/github/tag-date/deepio/gandalf)
![GitHub last commit](https://img.shields.io/github/last-commit/deepio/gandalf)
![GitHub repo size](https://img.shields.io/github/repo-size/deepio/gandalf)

The Symbolic Music File Evaluation Tool.
- Written with the newer format strings `python 3.6+`.
- Will not support `python 2.x`.
- Read the LICENSE.

### Installation
From a bash terminal, run these commands
```bash
# Install python poetry
pip3 install --user poetry
# Create a virtual environment, in this example it is named env
python3 -m venv env
# Enter the virtual environment
. ./env/bin/activate
# Install gandalf (from the project root)
poetry install
```


### Usage
- For up-to-date usage information, run `gandalf` or `gandalf --help`